<template>
  <!-- 安全计划任务子表信息 -->
  <div>
    <el-table
      ref="singleTable"
      :data="tableData"
      style="width: 100%"
      highlight-current-row
      @row-click="tableCurrentChange"
      @header-click="tableHeaderClick"
    >
      <el-table-column
        :key="k"
        label="任务名称"

        prop="name"
      >
        <template slot-scope="scope">
          <div v-if="scope.row.isEdit">

            <el-input
              v-model="scope.row.name"
              size="mini"
              clearable
              :maxlength="100"
            />
          </div>
          <span v-else>{{ scope.row.name }}</span>
        </template>
      </el-table-column>
      <el-table-column
        label="任务日期"
        width="130"
        prop="taskDate"
      >
        <template slot-scope="scope">
          <div v-if="scope.row.isEdit">

            <el-date-picker
              v-model="scope.row.taskDate"
              size="mini"
              clearable
              type="date"
              value-format="yyyy-MM-dd"
              placeholder="请选择任务日期时间"
              style="width:100%;"
            />
          </div>
          <span v-else>{{ scope.row.taskDate }}</span>
        </template>
      </el-table-column>
      <el-table-column
        label="工作描述"

        prop="description"
      >
        <template slot-scope="scope">
          <div v-if="scope.row.isEdit">

            <el-input
              v-model="scope.row.description"
              size="mini"
              clearable
              :maxlength="200"
            />
          </div>
          <span v-else>{{ scope.row.description }}</span>
        </template>
      </el-table-column>
      <el-table-column
        label="责任人"

        prop="taskUser"
      >
        <template slot-scope="scope">
          <div v-if="scope.row.isEdit">

            <el-select
              v-model="scope.row.taskUserValues"
              clearable
              filterable
              size="mini"
              reserve-keyword
              remote
              :remote-method="taskUserSelectRemoteMethod"
              :loading="taskUserSelectLoading"
              allow-create
              multiple
              style="width:100%"
              placeholder="请选择责任人"
            >
              <el-option
                v-for="item in taskUserSelectOptions"
                :key="item.fullname"
                :label="item.fullname"
                :value="item.fullname"
              />
            </el-select>
          </div>
          <span v-else>{{ scope.row.taskUser }}</span>
        </template>
      </el-table-column>
      <el-table-column
        label="备注"

        prop="memo"
      >
        <template slot-scope="scope">
          <div v-if="scope.row.isEdit">

            <el-input
              v-model="scope.row.memo"
              size="mini"
              clearable
              :maxlength="200"
            />
          </div>
          <span v-else>{{ scope.row.memo }}</span>
        </template>
      </el-table-column>

      <el-table-column align="right" width="90px" :index="999">
        <template slot="header">
          <el-button
            size="mini"
            type="warning"
            circle
            icon="el-icon-plus"
            @click="add"
          />
        </template>
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="danger"
            circle
            icon="el-icon-close"
            @click="del(scope.$index, scope.row)"
          />
        </template>
      </el-table-column>
    </el-table>
  </div>
</template>
<script>

import dictContracts from '@/components/dict/DictSelectUtils.js'
import CommonApi from '@/views/Manage/CommonApi.js'

export default {
  name: 'CmgtSaftyPlanTaskChildTable',
  components: {

  },
  props: {
    tableData: {
      type: Array,
      default: null
    }
  },
  data() {
    return {
      taskUserSelectOptions: [],
      taskUserSelectLoading: false,
      k: 0,
      currnetRow: null
    }
  },
  created() {
  },
  methods: {
    taskUserSelectRemoteMethod(query) {
      this.taskUserSelectLoading = true
      CommonApi.loadSelectOptions({ name: 'cmgtSaftySelectOptions.getUsers', query: query }, res => {
        this.taskUserSelectLoading = false
        this.taskUserSelectOptions = res
      })
    },
    add() {
      if (this.currnetRow) {
        this.currnetRow.isEdit = false
      }
      this.currnetRow = { isEdit: true }
      this.tableData.push(this.currnetRow)
      this.$refs.singleTable.setCurrentRow(this.tableData[this.tableData.length - 1])
    //   this.$nextTick(() => {
    //     this.$refs.singleTable.bodyWrapper.scrollTop = this.$refs.singleTable.bodyWrapper.scrollHeight
    //   })
    },
    del(index, row) {
      this.tableData.splice(index, 1)
    },
    tableCurrentChange(row) {
      if (this.currnetRow) {
        this.currnetRow.isEdit = false
      }
      row.isEdit = true
      this.currnetRow = row
      this.k++
    },
    tableHeaderClick(col) {
      if (!(col.index && col.index === 999)) {
        this.tableData.forEach(item => {
          item.isEdit = false
        })
        this.currnetRow = null
      }
    }
  }
}
</script>

